# PRIME NUMBER CHECKER
#### THIS PACKAGE IS USED TO FIND WHETHER THE GIVEN NUMBER IS PRIME NUMBER OR NOT


## Installation 
Run the following code to install this package:
   '''cmd pip install pfc_prime_number_or_not'''
##contributer: KANIMOZHI N